
# PLEASE NOTE:
# This code follows the coding outlines in our technical appendix. For more 
# information, please read the original paper and the technical appendix. Both
# can be found here: http://www.pnas.org/content/early/2018/10/18/1808793115

# This code is structured along the six dimensions of integration. For some 
# questions/dimensions the values assigned to answer options need no further
# recoding. For other questions, some recoding is neccessary. 

# This code will not compute integration scores for respondents that didn't 
# answer all questions. These cases will result in missing values. Depending
# on their specific project, researchers should use different strategies on how
# to deal with missing values. 
# This code was written by Niklas Harder

# Set your working directory. The directory should include one /code folder for
# code and one /data folder for data.

setwd("Your directory")

# Read data. This command was written to read data that was downloaded from 
# Qualtrics as a .csv file through the legacy export function. 

df <- read.csv("data/IPL12_simulatedData.csv", sep = ",", header = TRUE, skip = 1, encoding = "UTF-8", 
         stringsAsFactors = FALSE)

# Check if all recorded answers finished the survey
sum(df$Finished) == nrow(df)

# Load needed packages
require(scales)
require(reshape)

# Review psychological integration ----------------------------------------

# As defined in the Qualtrics surevey, all answers in psychological integration
# are already coded the right way. To check for missings, table all variables:

print(lapply(df[, c("connectionHc", "outsider")], 
             table, useNA = "ifany"))

# You can now create and rescale the psychological integration index
df$psy12 <- df$connectionHc + df$outsider 
df$psy12s <- rescale(df$psy12, to = c(0, 1), from = c(2, 10))


# Review navigational integration -----------------------------------------

# All items are already coded the right way and can be inspected:

print(lapply(df[, c("seeDoctor", "searchJob")], 
             table, useNA = "ifany"))

# You can now create and rescale the navigational integration index
df$nav12 <- df$seeDoctor + df$searchJob
df$nav12s <- rescale(df$nav12, to = c(0, 1), from = c(2, 10))


# Review economic integration ---------------------------------------------

# In this section, we need the respondents' household size. First we need to 
# check if any respondent is form a household of more then 15 members. If this
# is the case the answer needs to be recoded.

# Household
table(df$hhsize, useNA = "ifany")

if (sum(df$hhsize == 99, na.rm = TRUE) != 0) {
  stop("There are households with more than 15 members. The variable needs recoding")
} else {
  print("All households have 15 or fewer members. No recoding neccessary")
}

# In this example, households of more than 15 members are assigned a random
# value between 16 and 20.
df$hhsize[df$hhsize == 99] <- sample(16:20, sum(df$hhsize == 99), replace = TRUE)


# If a respondent doesn't answer the income question, we use 'unfolding' 
# questions to narrow down that respondent's income. These questions need to
# be recoded to the middle value of the estimated income interval.  

# Recode unfolding answers
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 0 & df$up1stQ == 0)] <- 15000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 0 & df$up1stQ == 1)] <- 35000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 1 & df$up4thQ == 1)] <- 165000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 1 & df$up4thQ == 0 & df$up3rdQ == 0)] <- 60000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 1 & df$up4thQ == 0 & df$up3rdQ == 1)] <- 90000


# Now recode all other values to the middle of the category, 
# for the first cat I use $1000 per month, 
# for highest I add the interval of 9 to highets.
df$hhInc[df$hhInc == 1] <- 12000
df$hhInc[df$hhInc == 2] <- 20000
df$hhInc[df$hhInc == 3] <- 30000
df$hhInc[df$hhInc == 4] <- 40000
df$hhInc[df$hhInc == 5] <- 52500
df$hhInc[df$hhInc == 6] <- 67500
df$hhInc[df$hhInc == 7] <- 82500
df$hhInc[df$hhInc == 8] <- 105000
df$hhInc[df$hhInc == 9] <- 142500
df$hhInc[df$hhInc == 10] <- 210000

# Check if there are still NAs
table(df$hhInc, useNA = "ifany")

## Divide recoded hhInc by sqrt of hhsize
df$equHhInc <- df$hhInc / sqrt(df$hhsize)

# Based on  weighted ACS data (2014), I estimate the median US equivalised 
# household income with to be $42,900 

gmeh <- 42900

# I then make 5 categories
df$income <- NA
df$income[which(df$equHhInc < (gmeh/3))] <- 1
df$income[which(df$equHhInc > (gmeh/3) &
                  df$equHhInc < (gmeh/1.5))] <- 2
df$income[which(df$equHhInc >(gmeh/1.5) & df$equHhInc < gmeh)] <- 3
df$income[which(df$equHhInc > gmeh & df$equHhInc < (gmeh + (gmeh/3)))] <- 4
df$income[which(df$equHhInc > (gmeh + (gmeh/3)))] <- 5

table(df$income, useNA = "ifany")


# Employment, ther is an open text field. Check if open answers need manual recoding
table(df$workStatus, useNA = "ifany")

{
  if (sum(df$workStatus[grep("[[:alnum:]]", df$workStatus.TEXT)] == 10) != 0)
  {
    stop("There are text values in workStatus that have not been recoded")
  }
  
  print("All text values in workStatus have been recoded")
}

# Recode employment according to ACS categories

df$employment <- ifelse(df$workStatus == 1 |
                              df$workStatus == 7,
                            5,
                            ifelse(df$workStatus == 2 |
                                     df$workStatus == 5 |
                                     df$workStatus == 6 |
                                     df$workStatus == 8 |
                                     df$workStatus == 9 |
                                     df$workStatus == 10,
                                   3,
                                   ifelse(df$workStatus == 3 |
                                            df$workStatus == 4,
                                          1,
                                          NA)))

table(df$employment, useNA = "ifany")


# You can now create and rescale the economic integration index
df$econ12 <- df$income + df$employment
df$econ12s <- rescale(df$econ12, to = c(0, 1), from = c(2, 10))


# Review social integration ----------------------------------------------

# Both questions are already coded the right
# way:

print(lapply(df[, c("dinner", "contactsInUs")], 
             table, useNA = "ifany"))

# You can now create and rescale the social integration index
df$soc12 <- df$dinner + df$contactsInUs
df$soc12s <- rescale(df$soc12, to = c(0, 1), from = c(2, 10))


# Review political integration --------------------------------------------

# The questions on political discussions and political understanding are
# already coded in the right direction and can be inspected

print(lapply(df[, c("polUnderstanding",
                    "polDiscuss")], table, useNA = "ifany"))

# You can now create and rescale the political integration index
df$pol12 <- df$polUnderstanding + df$polDiscuss 
df$pol12s <- rescale(df$pol12, to = c(0, 1), from = c(2, 10))


# Review linguistic integration -------------------------------------------

# All questions are already coded the right way
lapply(df[, c("read", "speak")], table, useNA = "ifany")

# You can now create and rescale the linguistic integration index
df$ling12 <- df$read + df$speak 
df$ling12s <- rescale(df$ling12, to = c(0, 1), from = c(2, 10))


# Create IPL-12 -----------------------------------------------------------

df$ipl12 <- df$pol12 + df$econ12 + df$soc12 + df$psy12 + df$ling12 + df$nav12
df$ipl12s <- rescale(df$ipl12, to = c(0, 1), from = c(12, 60))







