* PLEASE NOTE:
* This code follows the coding outlines in our technical appendix. For more 
* information, please read the original paper and the technical appendix. Both
* can be found here: http://www.pnas.org/content/early/2018/10/18/1808793115

* This code is structured along the six dimensions of integration. For some 
* questions/dimensions the values assigned to answer options need no further
* recoding. For other questions, some recoding is neccessary. 

* This code will not compute integration scores for respondents that didn't 
* answer all questions. These cases will result in missing values. Depending
* on their specific project, researchers should use different strategies on how
* to deal with missing values. 
* This code was written by Michael Hotard

* This script recodes data from the IPL-12 Integration Index
* The input is a csv file downloaded from the Qualtrics survey platform using the legacy export function


***********************************************************************************
* Load data
**********************************************************************************/

* Set your working directory. The directory should include one code folder for code and one data folder for data. 
cd ""

* Read data. This command was written to read data that was downloaded from  Qualtrics as a .csv file through the legacy export function. 
* NOTE: the variable names are in the second row in this file format
import delimited IPL24_simulatedData.csv, varnames(2) clear

* Check if all recorded answers finished the survey
tab finished, missing



***********************************************************************************
* Psychological integration
***********************************************************************************

* As defined in the Qualtrics surevey, all answers in psychological integration are already coded correctly. To check for missings, table all variables:

table connectionhc, missing
table outsider, missing

*  You can now create and rescale the psychological integration index

gen psy12 = connectionhc + outsider
gen psy12s = psy12/8- 1/4


***********************************************************************************
* Navigational integration
***********************************************************************************

* The first three items are already coded correctly and can be inspected:

table seedoctor, missing
table searchjob, missing


*  You can now create and rescale the navigational integration index


gen nav12 = seedoctor + searchjob 
gen nav12s = nav12/8- 1/4


***********************************************************************************
* Economic integration
***********************************************************************************

* In this section, we need the respondents' household size. First we need to 
* check if any respondent is form a household of more then 15 members. If this
* is the case the answer needs to be recoded.

* Household
table hhsize, missing

* In this example, households of more than 15 members are assigned a random
* value between 16 and 20.

* generating a random number between 16 and 20 for hhsize == 99

replace hhsize = int(16 + 5 * uniform()) if hhsize == 99

* If a respondent doesn't answer the income question, we use 'unfolding' 
* questions to narrow down that respondent's income. These questions need to
* be recoded to the middle value of the estimated income interval.  

replace hhinc = 15000 if hhinc == . & up2ndq == 0 & up1stq == 0 

replace hhinc = 35000 if hhinc == . & up2ndq == 0 & up1stq == 1

replace hhinc = 165000 if hhinc == . & up2ndq == 1 & up4thq == 1

replace hhinc = 60000 if hhinc == . & up2ndq == 1 & up4thq == 0 & up3rdq == 0

replace hhinc = 90000 if hhinc == . & up2ndq == 1 & up4thq == 0 & up3rdq == 1

* Now recode all other values to the middle of the category, 
* for the first cat I use $1000 per month, 
* for highest I add the interval of 9 to highest.

replace hhinc = 12000 if hhinc == 1
replace hhinc = 20000 if hhinc == 2
replace hhinc = 30000 if hhinc == 3
replace hhinc = 40000 if hhinc == 4
replace hhinc = 52500 if hhinc == 5
replace hhinc = 67500 if hhinc == 6
replace hhinc = 82500 if hhinc == 7
replace hhinc = 105000 if hhinc == 8
replace hhinc = 142500 if hhinc == 9
replace hhinc = 210000 if hhinc == 10


* Check if there are still NAs
table hhinc

* Divide recoded hhInc by sqrt of hhsize

gen equhhinc = hhinc / sqrt(hhsize)

* Based on  weighted ACS data (2014), estimate the median US equivalised 
* household income with to be $42,900 

gen GMEH = 42900

* The cutoff points for the scores are
* GMEH / 3
* GMEH / 1.5
* GMEH 
* GMEH + GMEH /3

* the script then makes 5 categories

gen income = .
replace income = 1 if equhhinc < GMEH/3
replace income = 2 if equhhinc >= GMEH/3 & equhhinc < GMEH / 1.5
replace income = 3 if equhhinc >=  GMEH / 1.5  & equhhinc < GMEH
replace income = 4 if equhhinc >= GMEH & equhhinc < (GMEH + (GMEH / 3))
replace income = 5 if equhhinc > (GMEH + (GMEH / 3)) & equhhinc != .

table income, missing

* in employment, there is an open text field. Check if open answers need manual recoding

table workstatus, missing

* after any manual recoding into one of the categories, recode the values to the 1-5 scale

gen employment = .

replace employment = 5 if workstatus == 1
replace employment = 5 if workstatus == 7

replace employment = 3 if workstatus == 2
replace employment = 3 if workstatus == 5
replace employment = 3 if workstatus == 6
replace employment = 3 if workstatus == 8
replace employment = 3 if workstatus == 9
replace employment = 3 if workstatus == 10

replace employment = 1 if workstatus == 3
replace employment = 1 if workstatus == 4

table employment


gen econ12 = income + employment
gen econ12s = econ12/8- 1/4


***********************************************************************************
* Social integration
***********************************************************************************


* The dinner, contact, and the favors questions are already coded correctly:

table dinner, missing
table contactsinus, missing

*  You can now create and rescale the social integration index

gen soc12 = dinner + contactsinus
gen soc12s = soc12/8- 1/4


***********************************************************************************
* Political integration
***********************************************************************************

* The questions on political discussions and political understanding are
* already coded in the right direction and can be inspected

table polunderstanding, missing
table poldiscuss, missing


* You can now create and rescale the political integration index


gen pol12 = polunderstanding + poldiscuss 
gen pol12s = pol12/8- 1/4


***********************************************************************************
* Linguistic integration
***********************************************************************************

*All the linguistic questions are already coded correctly

table read, missing
table speak, missing

* You can now create and rescale the linguistic integration index


gen ling12 = read + speak 
gen ling12s = ling12/8- 1/4

***********************************************************************************
* IPL-12 Scores
***********************************************************************************


gen ipl12 = pol12 + econ12 + soc12 + psy12 + ling12 + nav12
gen ipl12s = (ipl12 / 48) - (1/4)

exit

             


